@@ -1,11 +1,13 @@
 package Text::MagicTemplate::Utilities;
-$VERSION = '0.03';
+$VERSION = '0.04';
 use Exporter ();
 push @ISA, qw( Exporter );
-@EXPORT =  qw( _block );
+@EXPORT_OK =  qw( _block );
 
 use strict; no strict "refs";
 
+## set_identifier_output
+
 sub _block
 {
     my ($s, $content, $ref) = @_;
@@ -35,4 +37,9 @@ sub _label
     $output;
 }
 
+## end set_identifier_output
+
+
+
+
 1;
\ No newline at end of file
